@@ -1,12 +1,11 @@
+from typing import Optional
+
 from vkbottle_types.responses import streaming, base
-from typing import Optional, Any, List
 from .base_category import BaseCategory
 
 
 class StreamingCategory(BaseCategory):
-    async def get_server_url(
-        self,
-    ) -> streaming.GetServerUrlResponseModel:
+    async def get_server_url(self, **kwargs) -> streaming.GetServerUrlResponseModel:
         """Allows to receive data for the connection to Streaming API."""
 
         params = self.get_set_params(locals())
@@ -15,7 +14,7 @@ class StreamingCategory(BaseCategory):
         )
 
     async def set_settings(
-        self, monthly_tier: Optional[str] = None
+        self, monthly_tier: Optional[str] = None, **kwargs
     ) -> base.OkResponseModel:
         """streaming.setSettings method
         :param monthly_tier:
